@@ -1,15 +1,19 @@
-my $title = translate('editTranslation');
+use utf8;
+use warnings;
+no warnings 'redefine';
+use vars qw($title $txt @l);
+$title = translate('editTranslation');
 print '<div class="ShowTables marginTop">';
 
 loadTranslate($m_hrSettings->{translate});
 *m_hrLng = \$MySQL::Admin::Translate::lang;
-my @l;
+
 foreach my $key (sort keys %{$m_hrLng}) {
     push @l, $key;
 }
-my $txt = translate('translate');
+$txt = translate('translate');
 print start_form(
-                 -method   => "POST",
+                 -method   => 'POST',
                  -onSubmit => "submitForm(this,'showaddTranslation','$txt');return false;",
                  -action   => "$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}"
                 )
@@ -17,7 +21,7 @@ print start_form(
   . hidden(
            {
             -name    => 'do',
-            -default => '1'
+            -default => '1.01'
            },
            'true'
           )
@@ -25,7 +29,7 @@ print start_form(
           {
            -align  => 'center',
            -border => 0,
-           width   => "70%"
+           width   => '70%'
           },
           caption('Add translation'),
           Tr(
@@ -33,11 +37,11 @@ print start_form(
                -align  => 'left',
                -valign => 'top'
               },
-              td("Key"),
+              td('Key'),
               td(
                   textfield(
                             {
-                             -style => "width:100%",
+                             -style => 'width:100%',
                              -name  => 'key'
                             },
                             'name'
@@ -53,7 +57,7 @@ print start_form(
               td(
                   textfield(
                             {
-                             -style => "width:100%",
+                             -style => 'width:100%',
                              -name  => 'txt'
                             },
                             'txt'
@@ -65,13 +69,13 @@ print start_form(
                -align  => 'left',
                -valign => 'top'
               },
-              td("Language "),
+              td('Language'),
               td(
                   popup_menu(
-                             -onchange => "setLang(this.options[this.options.selectedIndex].value)",
+                             -onchange => 'setLang(this.options[this.options.selectedIndex].value)',
                              -name     => 'lang',
                              -values   => [@l],
-                             -style    => "width:100%"
+                             -style    => 'width:100%'
                             ),
                 )
             ),
