@@ -1,56 +1,56 @@
 $VAR1 = {
-          'news' => {
-                      'captcha' => 3,
-                      'messages' => '5',
-                      'right' => 5
-                    },
-          'defaultAction' => 'ShowDatabases',
+          'htmlright' => '2',
+          'mod' => 'n',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'language' => 'en',
-          'floodtime' => 10,
           'database' => {
                           'host' => 'localhost',
-                          'CurrentHost' => 'localhost',
-                          'CurrentUser' => 'root',
                           'password' => '',
-                          'CurrentDb' => 'MySQLAdmin',
-                          'CurrentPass' => '',
                           'user' => 'root',
-                          'name' => 'MySQLAdmin'
+                          'CurrentHost' => 'localhost',
+                          'CurrentPass' => '',
+                          'name' => 'MySQLAdmin',
+                          'CurrentDb' => 'MySQLAdmin',
+                          'CurrentUser' => 'root'
                         },
+          'files' => {
+                       'group' => 'lze',
+                       'owner' => 'lze',
+                       'chmod' => '0755'
+                     },
+          'news' => {
+                      'captcha' => 3,
+                      'right' => 5,
+                      'messages' => '5'
+                    },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'saveTranslate' => '0',
+          'defaultAction' => 'ShowDatabases',
+          'uploads' => {
+                         'chmod' => 438,
+                         'enabled' => 1,
+                         'maxlength' => '2100000000000000',
+                         'path' => '/var/www/htdocs//download',
+                         'right' => 2
+                       },
           'admin' => {
                        'password' => 'testpass'
                      },
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'mod' => 'n',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'files' => {
-                       'owner' => 'lze',
-                       'chmod' => '0755',
-                       'group' => 'lze'
-                     },
+          'floodtime' => 10,
+          'size' => '16',
           'cgi' => {
+                     'expires' => '+1y',
+                     'cookiePath' => '/',
+                     'serverName' => 'http://localhost',
+                     'DocumentRoot' => '/var/www/htdocs/',
                      'bin' => '/var/www/cgi-bin',
                      'style' => 'mysql',
-                     'title' => 'MySQL::Admin',
-                     'cookiePath' => '/',
-                     'expires' => '+1y',
-                     'serverName' => 'http://localhost',
-                     'DocumentRoot' => '/var/www/htdocs/'
+                     'title' => 'MySQL::Admin'
                    },
-          'size' => '16',
-          'uploads' => {
-                         'chmod' => 438,
-                         'path' => '/var/www/htdocs//download',
-                         'right' => 2,
-                         'maxlength' => '2100000000000000',
-                         'enabled' => 1
-                       },
-          'saveTranslate' => '0',
-          'version' => '0.99',
-          'htmlright' => '2',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'version' => '1.01',
           'tree' => {
                       'links' => '/var/www/cgi-bin/config/links.pl',
                       'navigation' => '/var/www/cgi-bin/config/tree.pl'
