@@ -25,7 +25,7 @@ $VAR1 = [
      'style'       => '',
      'onkeydown'   => '',
      'coords'      => '',
-     '1'           => undef,
+     '1.01'           => undef,
      'charset'     => '',
      'onclick'     => '',
      'dir'         => '',
@@ -52,7 +52,7 @@ $VAR1 = [
      'tabindex'    => '',
      'rel'         => '',
      'charset'     => '',
-     '1'           => undef,
+     '1.01'           => undef,
      'coords'      => '',
      'onkeydown'   => '',
      ''            => 'save',
