@@ -29,7 +29,7 @@ require Exporter;
 @HTML::Editor::EXPORT_OK   = qw(initEditor show JsEnabled );
 %HTML::Editor::EXPORT_TAGS = ('all' => [qw(initEditor show JsEnabled)]);
 
-$HTML::Editor::VERSION = '0.99';
+$HTML::Editor::VERSION = '1.01';
 
 $DefaultClass = 'HTML::Editor' unless defined $HTML::Editor::DefaultClass;
 
@@ -73,7 +73,7 @@ sub new {
 
                 class    => "min",
 
-                attach   => '1',
+                attach   => '1.01',
 
                 path   => "/srv/www/cgi-bin/templates",#default : '/srv/www/cgi-bin/templates'
 
